@@ -21,16 +21,18 @@ KItemListView *KItemListViewAccessible::view() const
     return qobject_cast<KItemListView *>(object());
 }
 
-KItemListViewAccessible::KItemListViewAccessible(KItemListView *view_)
+KItemListViewAccessible::KItemListViewAccessible(KItemListView *view_, KItemListContainerAccessible *parent)
     : QAccessibleObject(view_)
+    , m_parent(parent)
 {
     Q_ASSERT(view());
+    Q_CHECK_PTR(parent);
     m_cells.resize(childCount());
 }
 
 KItemListViewAccessible::~KItemListViewAccessible()
 {
-    for (AccessibleIdWrapper idWrapper : qAsConst(m_cells)) {
+    for (AccessibleIdWrapper idWrapper : std::as_const(m_cells)) {
         if (idWrapper.isValid) {
             QAccessible::deleteAccessibleInterface(idWrapper.id);
         }
@@ -208,8 +210,7 @@ QAccessibleInterface *KItemListViewAccessible::childAt(int x, int y) const
 
 QAccessibleInterface *KItemListViewAccessible::parent() const
 {
-    // FIXME: return KItemListContainerAccessible here
-    return nullptr;
+    return m_parent;
 }
 
 int KItemListViewAccessible::childCount() const
