@@ -1088,8 +1088,14 @@ void KStandardItemListWidget::updatePixmapCache()
         }
 
         if (m_isCut) {
-            KIconEffect *effect = KIconLoader::global()->iconEffect();
-            m_pixmap = effect->apply(m_pixmap, KIconLoader::Desktop, KIconLoader::DisabledState);
+#if KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+            KIconEffect::toDisabled(m_pixmap);
+#else
+            QImage img = m_pixmap.toImage();
+            KIconEffect::toGray(img, 1);
+            KIconEffect::semiTransparent(img);
+            m_pixmap = QPixmap::fromImage(img);
+#endif
         }
 
         if (m_isHidden) {
@@ -1162,13 +1168,13 @@ void KStandardItemListWidget::updatePixmapCache()
     // Prepare the pixmap that is used when the item gets hovered
     if (isHovered()) {
         m_hoverPixmap = m_pixmap;
-        KIconEffect *effect = KIconLoader::global()->iconEffect();
-        // In the KIconLoader terminology, active = hover.
-        if (effect->hasEffect(KIconLoader::Desktop, KIconLoader::ActiveState)) {
-            m_hoverPixmap = effect->apply(m_pixmap, KIconLoader::Desktop, KIconLoader::ActiveState);
-        } else {
-            m_hoverPixmap = m_pixmap;
-        }
+#if KICONTHEMES_VERSION >= QT_VERSION_CHECK(6, 5, 0)
+        KIconEffect::toActive(m_hoverPixmap);
+#else
+        QImage img = m_pixmap.toImage();
+        KIconEffect::toGamma(img, 0.7);
+        m_hoverPixmap = QPixmap::fromImage(img);
+#endif
     } else if (hoverOpacity() <= 0.0) {
         // No hover animation is ongoing. Clear m_hoverPixmap to save memory.
         m_hoverPixmap = QPixmap();
@@ -1256,11 +1262,7 @@ QString KStandardItemListWidget::elideRightKeepExtension(const QString &text, in
         if (elidingWidth > extensionWidth && extensionLength < 6 && (float(extensionWidth) / float(elidingWidth)) < 0.3) {
             // if we have room to display the file extension and the extension is not too long
             QString ret = m_customizedFontMetrics.elidedText(text.chopped(extensionLength), Qt::ElideRight, elidingWidth - extensionWidth);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-            ret.append(text.rightRef(extensionLength));
-#else
             ret.append(QStringView(text).right(extensionLength));
-#endif
             return ret;
         }
     }
@@ -1513,8 +1515,8 @@ void KStandardItemListWidget::updateAdditionalInfoTextColor()
     if (m_customTextColor.isValid()) {
         c1 = m_customTextColor;
     } else if (isSelected() && hasFocus && (m_layout != DetailsLayout || m_highlightEntireRow)) {
-        // The detail text colour needs to match the main text (HighlightedText) for the same level
-        // of readability. We short circuit early here to avoid interpolating with another colour.
+        // The detail text color needs to match the main text (HighlightedText) for the same level
+        // of readability. We short circuit early here to avoid interpolating with another color.
         m_additionalInfoTextColor = styleOption().palette.color(QPalette::HighlightedText);
         return;
     } else {
